@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,17 +7,19 @@
 #ifndef ABSTRACTADDRESSBOOK_H
 #define ABSTRACTADDRESSBOOK_H
 
-#include <AkonadiCore/Collection>
 #include "abstractbase.h"
 #include "libimportwizard_export.h"
+#include <AkonadiCore/Collection>
 
-namespace KContacts {
+namespace KContacts
+{
 class Addressee;
 class ContactGroup;
 }
 
 class KJob;
-namespace LibImportWizard {
+namespace LibImportWizard
+{
 class LIBIMPORTWIZARD_EXPORT AbstractAddressBook : public LibImportWizard::AbstractBase
 {
     Q_OBJECT
