@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,6 +15,9 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <QUrl>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <QTextCodec>
+#endif
 
 #include "balsaplugin_debug.h"
 #include <QFile>
@@ -59,8 +62,8 @@ void BalsaAddressBook::readAddressBook(const KConfigGroup &grp)
         ldap.useTLS = (grp.readEntry(QStringLiteral("EnableTLS")) == QLatin1String("true"));
         ldap.ldapUrl = QUrl(grp.readEntry(QStringLiteral("Host")));
         ldap.port = ldap.ldapUrl.port();
-        //TODO: verify
-        const QString bookDN = grp.readEntry(QStringLiteral("BookDN"));  //TODO ?
+        // TODO: verify
+        const QString bookDN = grp.readEntry(QStringLiteral("BookDN")); // TODO ?
         ImportWizardUtil::mergeLdap(ldap);
         addAddressBookImportInfo(i18n("Ldap created"));
     } else if (type == QLatin1String("LibBalsaAddressBookGpe")) {
@@ -73,7 +76,11 @@ void BalsaAddressBook::readAddressBook(const KConfigGroup &grp)
             QFile file(path);
             if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
                 QTextStream stream(&file);
-                stream.setCodec("ISO 8859-1");
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+                stream.setCodec(QTextCodec::codecForName("ISO-8859-1"));
+#else
+                stream.setEncoding(QStringConverter::Encoding::Latin1);
+#endif
 
                 const QString wholeFile = stream.readAll();
                 const QDateTime dtDefault = QFileInfo(file).lastModified();
